Class: Low::Events::FileEvent
- Inherits:
-
LowEvent
- Object
- LowEvent
- Low::Events::FileEvent
- Defined in:
- lib/events/file_event.rb
Instance Attribute Summary collapse
-
#file ⇒ Object
readonly
Returns the value of attribute file.
-
#request ⇒ Object
readonly
Returns the value of attribute request.
Instance Method Summary collapse
-
#initialize(file:, request: nil) ⇒ FileEvent
constructor
TODO: For RouteEvent/FileEvent parse and provide query params as attributes on the event.
Constructor Details
#initialize(file:, request: nil) ⇒ FileEvent
TODO: For RouteEvent/FileEvent parse and provide query params as attributes on the event.
11 12 13 14 15 16 |
# File 'lib/events/file_event.rb', line 11 def initialize(file:, request: nil) super(key: self.class) @file = file @request = request end |
Instance Attribute Details
#file ⇒ Object (readonly)
Returns the value of attribute file.
8 9 10 |
# File 'lib/events/file_event.rb', line 8 def file @file end |
#request ⇒ Object (readonly)
Returns the value of attribute request.
8 9 10 |
# File 'lib/events/file_event.rb', line 8 def request @request end |